# coding: utf-8

"""
    Passage Management API

    Passage's management API to manage your Passage apps and users.

    The version of the OpenAPI document: 1
    Contact: support@passage.id
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class FontFamily(str, Enum):
    """
    Body font family
    """

    """
    allowed enum values
    """
    HELVETICA = 'Helvetica'
    ARIAL = 'Arial'
    ARIAL_BLACK = 'Arial Black'
    VERDANA = 'Verdana'
    TAHOMA = 'Tahoma'
    TREBUCHET_MS = 'Trebuchet MS'
    IMPACT = 'Impact'
    GILL_SANS = 'Gill Sans'
    TIMES_NEW_ROMAN = 'Times New Roman'
    GEORGIA = 'Georgia'
    PALATINO = 'Palatino'
    BASKERVILLE = 'Baskerville'
    ANDALÉ_MONO = 'Andalé Mono'
    COURIER = 'Courier'
    LUCIDA = 'Lucida'
    MONACO = 'Monaco'
    BRADLEY_HAND = 'Bradley Hand'
    BRUSH_SCRIPT_MT = 'Brush Script MT'
    LUMINARI = 'Luminari'
    COMIC_SANS_MS = 'Comic Sans MS'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of FontFamily from a JSON string"""
        return cls(json.loads(json_str))


